==> huaweicloudsdkddm-3.1.141-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/database_dn_instances.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DatabaseDnInstances:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'user_name': 'str',
        'user_password': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_name': 'user_name',
        'user_password': 'user_password'
    }

    def __init__(self, id=None, user_name=None, user_password=None):
        """DatabaseDnInstances

        The model defined in huaweicloud sdk

        :param id: 逻辑库关联的DN实例的id
        :type id: str
        :param user_name: 关联DN实例的用户名。
        :type user_name: str
        :param user_password: 关联DN实例的用户密码。
        :type user_password: str
        """
        
        

        self._id = None
        self._user_name = None
        self._user_password = None
        self.discriminator = None

        self.id = id
        self.user_name = user_name
        self.user_password = user_password

    @property
    def id(self):
        """Gets the id of this DatabaseDnInstances.

        逻辑库关联的DN实例的id

        :return: The id of this DatabaseDnInstances.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DatabaseDnInstances.

        逻辑库关联的DN实例的id

        :param id: The id of this DatabaseDnInstances.
        :type id: str
        """
        self._id = id

    @property
    def user_name(self):
        """Gets the user_name of this DatabaseDnInstances.

        关联DN实例的用户名。

        :return: The user_name of this DatabaseDnInstances.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this DatabaseDnInstances.

        关联DN实例的用户名。

        :param user_name: The user_name of this DatabaseDnInstances.
        :type user_name: str
        """
        self._user_name = user_name

    @property
    def user_password(self):
        """Gets the user_password of this DatabaseDnInstances.

        关联DN实例的用户密码。

        :return: The user_password of this DatabaseDnInstances.
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """Sets the user_password of this DatabaseDnInstances.

        关联DN实例的用户密码。

        :param user_password: The user_password of this DatabaseDnInstances.
        :type user_password: str
        """
        self._user_password = user_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatabaseDnInstances):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.1.154-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/database_dn_instances.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DatabaseDnInstances:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'user_name': 'str',
        'user_password': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_name': 'user_name',
        'user_password': 'user_password'
    }

    def __init__(self, id=None, user_name=None, user_password=None):
        r"""DatabaseDnInstances

        The model defined in huaweicloud sdk

        :param id: 逻辑库关联的DN实例的id
        :type id: str
        :param user_name: 关联DN实例的用户名。
        :type user_name: str
        :param user_password: 关联DN实例的用户密码。
        :type user_password: str
        """
        
        

        self._id = None
        self._user_name = None
        self._user_password = None
        self.discriminator = None

        self.id = id
        self.user_name = user_name
        self.user_password = user_password

    @property
    def id(self):
        r"""Gets the id of this DatabaseDnInstances.

        逻辑库关联的DN实例的id

        :return: The id of this DatabaseDnInstances.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this DatabaseDnInstances.

        逻辑库关联的DN实例的id

        :param id: The id of this DatabaseDnInstances.
        :type id: str
        """
        self._id = id

    @property
    def user_name(self):
        r"""Gets the user_name of this DatabaseDnInstances.

        关联DN实例的用户名。

        :return: The user_name of this DatabaseDnInstances.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        r"""Sets the user_name of this DatabaseDnInstances.

        关联DN实例的用户名。

        :param user_name: The user_name of this DatabaseDnInstances.
        :type user_name: str
        """
        self._user_name = user_name

    @property
    def user_password(self):
        r"""Gets the user_password of this DatabaseDnInstances.

        关联DN实例的用户密码。

        :return: The user_password of this DatabaseDnInstances.
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        r"""Sets the user_password of this DatabaseDnInstances.

        关联DN实例的用户密码。

        :param user_password: The user_password of this DatabaseDnInstances.
        :type user_password: str
        """
        self._user_password = user_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatabaseDnInstances):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
